[dpdk-dev] [RFC 09/14] net: add rte prefix to icmp defines

Olivier Matz olivier.matz at 6wind.com
Wed Oct 24 10:18:28 CEST 2018


Add 'RTE_' prefix to defines:
- rename IP_ICMP_ECHO_REPLY as RTE_IP_ICMP_ECHO_REPLY.
- rename IP_ICMP_ECHO_REQUEST as RTE_IP_ICMP_ECHO_REQUEST.

Signed-off-by: Olivier Matz <olivier.matz at 6wind.com>
---
 app/test-pmd/icmpecho.c   | 10 +++++-----
 lib/librte_net/rte_icmp.h |  4 ++--
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/lib/librte_net/rte_icmp.h b/lib/librte_net/rte_icmp.h
index d0309537e..3f8100a5f 100644
--- a/lib/librte_net/rte_icmp.h
+++ b/lib/librte_net/rte_icmp.h
@@ -32,8 +32,8 @@ struct rte_icmp_hdr {
 } __attribute__((__packed__));
 
 /* ICMP packet types */
-#define IP_ICMP_ECHO_REPLY   0
-#define IP_ICMP_ECHO_REQUEST 8
+#define RTE_IP_ICMP_ECHO_REPLY   0
+#define RTE_IP_ICMP_ECHO_REQUEST 8
 
 #ifdef __cplusplus
 }
diff --git a/app/test-pmd/icmpecho.c b/app/test-pmd/icmpecho.c
index 33b9e2ffd..4bf3fed64 100644
--- a/app/test-pmd/icmpecho.c
+++ b/app/test-pmd/icmpecho.c
@@ -428,7 +428,7 @@ reply_to_icmp_echo_rqsts(struct fwd_stream *fs)
 		icmp_h = (struct rte_icmp_hdr *) ((char *)ip_h +
 					      sizeof(struct ipv4_hdr));
 		if (! ((ip_h->next_proto_id == IPPROTO_ICMP) &&
-		       (icmp_h->icmp_type == IP_ICMP_ECHO_REQUEST) &&
+		       (icmp_h->icmp_type == RTE_IP_ICMP_ECHO_REQUEST) &&
 		       (icmp_h->icmp_code == 0))) {
 			rte_pktmbuf_free(pkt);
 			continue;
@@ -452,7 +452,7 @@ reply_to_icmp_echo_rqsts(struct fwd_stream *fs)
 		 *     - switch the request IP source and destination
 		 *       addresses in the reply IP header,
 		 *     - keep the IP header checksum unchanged.
 		 * - set IP_ICMP_ECHO_REPLY in ICMP header.
 		 * ICMP checksum is computed by assuming it is valid in the
 		 * echo request and not verified.
 		 */
@@ -475,10 +475,10 @@ reply_to_icmp_echo_rqsts(struct fwd_stream *fs)
 			ip_h->src_addr = ip_h->dst_addr;
 			ip_h->dst_addr = ip_addr;
 		}
-		icmp_h->icmp_type = IP_ICMP_ECHO_REPLY;
+		icmp_h->icmp_type = RTE_IP_ICMP_ECHO_REPLY;
 		cksum = ~icmp_h->icmp_cksum & 0xffff;
-		cksum += ~htons(IP_ICMP_ECHO_REQUEST << 8) & 0xffff;
-		cksum += htons(IP_ICMP_ECHO_REPLY << 8);
+		cksum += ~htons(RTE_IP_ICMP_ECHO_REQUEST << 8) & 0xffff;
+		cksum += htons(RTE_IP_ICMP_ECHO_REPLY << 8);
 		cksum = (cksum & 0xffff) + (cksum >> 16);
 		cksum = (cksum & 0xffff) + (cksum >> 16);
 		icmp_h->icmp_cksum = ~cksum;
@@ -452,7 +452,7 @@ reply_to_icmp_echo_rqsts(struct fwd_stream *fs)
 		 *       addresses in the reply IP header,
 		 *     - keep the IP header checksum unchanged.
-		 * - set IP_ICMP_ECHO_REPLY in ICMP header.
+		 * - set RTE_IP_ICMP_ECHO_REPLY in ICMP header.
 		 * ICMP checksum is computed by assuming it is valid in the
 		 * echo request and not verified.
-- 
2.11.0



More information about the dev mailing list